@@ -196,6 +196,22 @@ pub fn get_pin_retries(hid_params: &[HidParam]) -> Result<i32> {
     Ok(pin.retries)
 }
 
+/// Set New PIN
+pub fn set_new_pin(hid_params: &[HidParam],pin: &str) -> Result<()> {
+    let device = FidoKeyHid::new(hid_params).map_err(Error::msg)?;
+    let cid = ctaphid::ctaphid_init(&device).map_err(Error::msg)?;
+    client_pin::set_pin(&device, &cid, pin)?;
+    Ok(())
+}
+
+/// Change PIN
+pub fn change_pin(hid_params: &[HidParam],current_pin: &str,new_pin: &str) -> Result<()> {
+    let device = FidoKeyHid::new(hid_params).map_err(Error::msg)?;
+    let cid = ctaphid::ctaphid_init(&device).map_err(Error::msg)?;
+    client_pin::change_pin(&device, &cid, current_pin, new_pin)?;
+    Ok(())
+}
+
 /// Registration command.Generate credentials(with PIN,non Resident Key)
 pub fn make_credential(
     hid_params: &[HidParam],
@@ -318,7 +334,7 @@ pub enum InfoParam {
     ExtensionsHmacSecret,
 }
 
-pub fn enable_info_param(hid_params: &[HidParam], info_param: InfoParam) -> Result<bool> {
+pub fn enable_info_param(hid_params: &[HidParam], info_param: &InfoParam) -> Result<bool> {
     let info = get_info::get_info(hid_params).map_err(Error::msg)?;
     let find = match info_param {
         InfoParam::VersionsU2Fv2 => "U2F_V2",
@@ -356,7 +372,7 @@ pub enum InfoOption {
 }
 pub fn enable_info_option(
     hid_params: &[HidParam],
-    info_option: InfoOption,
+    info_option: &InfoOption,
 ) -> Result<Option<bool>> {
     let info = get_info::get_info(hid_params).map_err(Error::msg)?;
     let find = match info_option {
@@ -364,7 +380,7 @@ pub fn enable_info_option(
         InfoOption::Up => "up",
         InfoOption::Uv => "uv",
         InfoOption::Plat => "plat",
-        InfoOption::ClinetPin => "plat",
+        InfoOption::ClinetPin => "clientPin",
         InfoOption::CredentialMgmtPreview => "credentialMgmtPreview",
         InfoOption::CredMgmt => "credMgmt",
         InfoOption::UserVerificationMgmtPreview => "userVerificationMgmtPreview",
